@@ -1,3 +1,4 @@
+import glob
 from contextlib import contextmanager
 import docker
 from subprocess import CalledProcessError
@@ -19,30 +20,44 @@ logger = logging.getLogger(__name__)
 
 ENCODING = 'utf-8'
 PLATFORM = get_arch_name()
-MANYLINUX1_IMAGE_ID = 'quay.io/pypa/manylinux1_{}'.format(PLATFORM)
-MANYLINUX2010_IMAGE_ID = 'quay.io/pypa/manylinux2010_{}'.format(PLATFORM)
-MANYLINUX2014_IMAGE_ID = 'quay.io/pypa/manylinux2014_{}:latest'.format(PLATFORM)
+MANYLINUX1_IMAGE_ID = f'quay.io/pypa/manylinux1_{PLATFORM}:latest'
+MANYLINUX2010_IMAGE_ID = f'quay.io/pypa/manylinux2010_{PLATFORM}:latest'
+MANYLINUX2014_IMAGE_ID = f'quay.io/pypa/manylinux2014_{PLATFORM}:latest'
+MANYLINUX_2_24_IMAGE_ID = f'quay.io/pypa/manylinux_2_24_{PLATFORM}:latest'
 if PLATFORM in {'i686', 'x86_64'}:
     MANYLINUX_IMAGES = {
-        'manylinux1': MANYLINUX1_IMAGE_ID,
-        'manylinux2010': MANYLINUX2010_IMAGE_ID,
-        'manylinux2014': MANYLINUX2014_IMAGE_ID,
+        'manylinux_2_5': MANYLINUX1_IMAGE_ID,
+        'manylinux_2_12': MANYLINUX2010_IMAGE_ID,
+        'manylinux_2_17': MANYLINUX2014_IMAGE_ID,
+        'manylinux_2_24': MANYLINUX_2_24_IMAGE_ID,
+    }
+    POLICY_ALIASES = {
+        'manylinux_2_5': ['manylinux1'],
+        'manylinux_2_12': ['manylinux2010'],
+        'manylinux_2_17': ['manylinux2014'],
     }
 else:
     MANYLINUX_IMAGES = {
-        'manylinux2014': MANYLINUX2014_IMAGE_ID,
+        'manylinux_2_17': MANYLINUX2014_IMAGE_ID,
+        'manylinux_2_24': MANYLINUX_2_24_IMAGE_ID,
+    }
+    POLICY_ALIASES = {
+        'manylinux_2_17': ['manylinux2014'],
     }
 DOCKER_CONTAINER_NAME = 'auditwheel-test-manylinux'
 PYTHON_MAJ_MIN = [str(i) for i in sys.version_info[:2]]
-PYTHON_ABI = 'cp{0}-cp{0}{1}'.format(''.join(PYTHON_MAJ_MIN), 'm' if sys.version_info.minor < 8 else '')
+PYTHON_ABI_MAJ_MIN = ''.join(PYTHON_MAJ_MIN)
+PYTHON_ABI_FLAGS = 'm' if sys.version_info.minor < 8 else ''
+PYTHON_ABI = f'cp{PYTHON_ABI_MAJ_MIN}-cp{PYTHON_ABI_MAJ_MIN}{PYTHON_ABI_FLAGS}'
 PYTHON_IMAGE_ID = 'python:' + '.'.join(PYTHON_MAJ_MIN)
 DEVTOOLSET = {
-    'manylinux1': 'devtoolset-2',
-    'manylinux2010': 'devtoolset-8',
-    'manylinux2014': 'devtoolset-9',
+    'manylinux_2_5': 'devtoolset-2',
+    'manylinux_2_12': 'devtoolset-8',
+    'manylinux_2_17': 'devtoolset-9',
+    'manylinux_2_24': 'devtoolset-not-present',
 }
 PATH_DIRS = [
-    '/opt/python/{}/bin'.format(PYTHON_ABI),
+    f'/opt/python/{PYTHON_ABI}/bin',
     '/opt/rh/{devtoolset}/root/usr/bin',
     '/usr/local/sbin',
     '/usr/local/bin',
@@ -54,7 +69,8 @@ PATH_DIRS = [
 PATH = {k: ':'.join(PATH_DIRS).format(devtoolset=v)
         for k, v in DEVTOOLSET.items()}
 WHEEL_CACHE_FOLDER = op.expanduser('~/.cache/auditwheel_tests')
-ORIGINAL_NUMPY_WHEEL = 'numpy-1.16.5-{}-linux_{}.whl'.format(PYTHON_ABI, PLATFORM)
+NUMPY_VERSION = '1.19.2'
+ORIGINAL_NUMPY_WHEEL = f'numpy-{NUMPY_VERSION}-{PYTHON_ABI}-linux_{PLATFORM}.whl'
 ORIGINAL_SIX_WHEEL = 'six-1.11.0-py2.py3-none-any.whl'
 
 
@@ -120,6 +136,7 @@ def io_folder(tmp_path):
     d.mkdir(exist_ok=True)
     return str(d)
 
+
 @contextmanager
 def tmp_docker_image(base, commands, setup_env={}):
     """Make a temporary docker image for tests
@@ -143,12 +160,14 @@ def tmp_docker_image(base, commands, setup_env={}):
         client = image.client
         client.images.remove(image.id)
 
+
 @pytest.fixture(scope='session')
 def docker_python_img():
     """The Python base image with up-to-date pip"""
-    with tmp_docker_image(PYTHON_IMAGE_ID, ['pip install pip']) as img_id:
+    with tmp_docker_image(PYTHON_IMAGE_ID, ['pip install -U pip']) as img_id:
         yield img_id
 
+
 @pytest.fixture(scope='session', params=MANYLINUX_IMAGES.keys())
 def any_manylinux_img(request):
     """Each manylinux image, with auditwheel installed.
@@ -164,6 +183,7 @@ def any_manylinux_img(request):
     ], env) as img_id:
         yield policy, img_id
 
+
 @pytest.fixture()
 def docker_python(docker_python_img, io_folder):
     with docker_container_ctx(docker_python_img, io_folder) as container:
@@ -179,7 +199,37 @@ def any_manylinux_container(any_manylinux_img, io_folder):
             env[key] = os.environ[key]
 
     with docker_container_ctx(manylinux_img, io_folder, env) as container:
-        yield '{}_{}'.format(policy, PLATFORM), container
+        platform_tag = '.'.join([f'{p}_{PLATFORM}'
+                                 for p in [policy] + POLICY_ALIASES.get(policy, [])])
+        yield f'{policy}_{PLATFORM}', platform_tag, container
+
+
+SHOW_RE = re.compile(
+    r'[\s](?P<wheel>\S+) is consistent with the following platform tag: "(?P<tag>\S+)"',
+    flags=re.DOTALL
+)
+TAG_RE = re.compile(
+    r'^manylinux_(?P<major>[0-9]+)_(?P<minor>[0-9]+)_(?P<arch>\S+)$'
+)
+
+
+def assert_show_output(manylinux_ctr, wheel, expected_tag, strict):
+    output = docker_exec(manylinux_ctr, f'auditwheel show /io/{wheel}')
+    output = output.replace('\n', ' ')
+    match = SHOW_RE.match(output)
+    assert match
+    assert match['wheel'] == wheel
+    if strict:
+        assert match['tag'] == expected_tag
+    else:
+        expected_match = TAG_RE.match(expected_tag)
+        assert expected_match, f"No match for tag {expected_tag}"
+        expected_glibc = (int(expected_match['major']), int(expected_match['minor']))
+        actual_match = TAG_RE.match(match['tag'])
+        assert actual_match, f"No match for tag {match['tag']}"
+        actual_glibc = (int(actual_match['major']), int(actual_match['minor']))
+        assert expected_match['arch'] == actual_match['arch']
+        assert actual_glibc <= expected_glibc
 
 
 def test_build_repair_numpy(any_manylinux_container, docker_python, io_folder):
@@ -187,8 +237,15 @@ def test_build_repair_numpy(any_manylinux_container, docker_python, io_folder):
 
     # First build numpy from source as a naive linux wheel that is tied
     # to system libraries (atlas, libgfortran...)
-    policy, manylinux_ctr = any_manylinux_container
-    docker_exec(manylinux_ctr, 'yum install -y atlas atlas-devel')
+    policy, tag, manylinux_ctr = any_manylinux_container
+    if policy.startswith('manylinux_2_24_'):
+        docker_exec(manylinux_ctr, 'apt-get update')
+        docker_exec(
+            manylinux_ctr,
+            'apt-get install -y --no-install-recommends libatlas-dev'
+        )
+    else:
+        docker_exec(manylinux_ctr, 'yum install -y atlas atlas-devel')
 
     if op.exists(op.join(WHEEL_CACHE_FOLDER, policy, ORIGINAL_NUMPY_WHEEL)):
         # If numpy has already been built and put in cache, let's reuse this.
@@ -199,8 +256,10 @@ def test_build_repair_numpy(any_manylinux_container, docker_python, io_folder):
         # and put the result in the cache folder to speed-up future build.
         # This part of the build is independent of the auditwheel code-base
         # so it's safe to put it in cache.
-        docker_exec(manylinux_ctr,
-            'pip wheel -w /io --no-binary=:all: numpy==1.16.5')
+        docker_exec(
+            manylinux_ctr,
+            f'pip wheel -w /io --no-binary=:all: numpy=={NUMPY_VERSION}'
+        )
         os.makedirs(op.join(WHEEL_CACHE_FOLDER, policy), exist_ok=True)
         shutil.copy2(op.join(io_folder, ORIGINAL_NUMPY_WHEEL),
                      op.join(WHEEL_CACHE_FOLDER, policy, ORIGINAL_NUMPY_WHEEL))
@@ -210,22 +269,14 @@ def test_build_repair_numpy(any_manylinux_container, docker_python, io_folder):
     assert 'manylinux' not in orig_wheel
 
     # Repair the wheel using the manylinux container
-    repair_command = (
-        'auditwheel repair  '
-        '--plat {policy} -w /io /io/{orig_wheel}'
-    ).format(policy=policy, orig_wheel=orig_wheel)
+    repair_command = \
+        f'auditwheel repair --plat {policy} --only-plat -w /io /io/{orig_wheel}'
     docker_exec(manylinux_ctr, repair_command)
     filenames = os.listdir(io_folder)
-
     assert len(filenames) == 2
-    repaired_wheels = [fn for fn in filenames if 'manylinux' in fn]
-    assert repaired_wheels == ['numpy-1.16.5-{}-{}.whl'.format(PYTHON_ABI, policy)]
-    repaired_wheel = repaired_wheels[0]
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/' + repaired_wheel)
-    assert (
-        'numpy-1.16.5-{abi}-{policy}.whl is consistent'
-        ' with the following platform tag: "{policy}"'
-    ).format(abi=PYTHON_ABI, policy=policy) in output.replace('\n', ' ')
+    repaired_wheel = f'numpy-{NUMPY_VERSION}-{PYTHON_ABI}-{tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, policy, False)
 
     # Check that the repaired numpy wheel can be installed and executed
     # on a modern linux image.
@@ -249,8 +300,15 @@ def test_build_wheel_with_binary_executable(any_manylinux_container, docker_pyth
                                             io_folder):
     # Test building a wheel that contains a binary executable (e.g., a program)
 
-    policy, manylinux_ctr = any_manylinux_container
-    docker_exec(manylinux_ctr, 'yum install -y gsl-devel')
+    policy, tag, manylinux_ctr = any_manylinux_container
+    if policy.startswith('manylinux_2_24_'):
+        docker_exec(manylinux_ctr, 'apt-get update')
+        docker_exec(
+            manylinux_ctr,
+            'apt-get install -y --no-install-recommends libgsl-dev'
+        )
+    else:
+        docker_exec(manylinux_ctr, 'yum install -y gsl-devel')
 
     docker_exec(
         manylinux_ctr,
@@ -263,22 +321,14 @@ def test_build_wheel_with_binary_executable(any_manylinux_container, docker_pyth
     assert 'manylinux' not in orig_wheel
 
     # Repair the wheel using the appropriate manylinux container
-    repair_command = (
-        'auditwheel repair --plat {policy} -w /io /io/{orig_wheel}'
-    ).format(policy=policy, orig_wheel=orig_wheel)
+    repair_command = \
+        f'auditwheel repair --plat {policy} --only-plat -w /io /io/{orig_wheel}'
     docker_exec(manylinux_ctr, repair_command)
     filenames = os.listdir(io_folder)
     assert len(filenames) == 2
-    repaired_wheels = [fn for fn in filenames if policy in fn]
-    # Wheel picks up newer symbols when built in manylinux2010
-    expected_wheel_name = 'testpackage-0.0.1-py3-none-{}.whl'.format(policy)
-    assert repaired_wheels == [expected_wheel_name]
-    repaired_wheel = repaired_wheels[0]
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/' + repaired_wheel)
-    assert (
-        'testpackage-0.0.1-py3-none-{policy}.whl is consistent'
-        ' with the following platform tag: "{policy}"'
-    ).format(policy=policy) in output.replace('\n', ' ')
+    repaired_wheel = f'testpackage-0.0.1-py3-none-{tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, policy, False)
 
     docker_exec(docker_python, 'pip install /io/' + repaired_wheel)
     output = docker_exec(
@@ -303,13 +353,13 @@ def test_build_wheel_with_image_dependencies(with_dependency, any_manylinux_cont
     #   available on policies pre-dating the policy matching the image being
     #   tested.
 
-    policy, manylinux_ctr = any_manylinux_container
+    policy, tag, manylinux_ctr = any_manylinux_container
 
     docker_exec(manylinux_ctr, [
         'bash', '-c',
-        'cd /auditwheel_src/tests/integration/testdependencies &&'
-        'WITH_DEPENDENCY={} python setup.py -v build_ext -f bdist_wheel -d '
-        '/io'.format(with_dependency)])
+        'cd /auditwheel_src/tests/integration/testdependencies && '
+        f'WITH_DEPENDENCY={with_dependency} python setup.py -v build_ext -f '
+        'bdist_wheel -d /io'])
 
     filenames = os.listdir(io_folder)
     orig_wheel = filenames[0]
@@ -321,8 +371,8 @@ def test_build_wheel_with_image_dependencies(with_dependency, any_manylinux_cont
 
     policy_priority = get_priority_by_name(policy)
     older_policies = \
-        [p for p in MANYLINUX_IMAGES.keys()
-         if policy_priority < get_priority_by_name('{}_{}'.format(p, PLATFORM))]
+        [f'{p}_{PLATFORM}' for p in MANYLINUX_IMAGES.keys()
+         if policy_priority < get_priority_by_name(f'{p}_{PLATFORM}')]
     for target_policy in older_policies:
         # we shall fail to repair the wheel when targeting an older policy than
         # the one matching the image
@@ -339,30 +389,17 @@ def test_build_wheel_with_image_dependencies(with_dependency, any_manylinux_cont
         repair_command.format(policy=policy, orig_wheel=orig_wheel)])
     filenames = os.listdir(io_folder)
     assert len(filenames) == 2
-    repaired_wheels = [fn for fn in filenames if policy in fn]
-    expected_wheel_name = \
-        'testdependencies-0.0.1-{}-{}.whl'.format(PYTHON_ABI, policy)
-    assert repaired_wheels == [expected_wheel_name]
-    repaired_wheel = repaired_wheels[0]
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/' + repaired_wheel)
-    assert (
-        'testdependencies-0.0.1-{abi}-{policy}.whl is consistent'
-        ' with the following platform tag: "{policy}"'
-    ).format(abi=PYTHON_ABI, policy=policy) in output.replace('\n', ' ')
+    repaired_wheel = f'testdependencies-0.0.1-{PYTHON_ABI}-{tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, policy, True)
 
     # check the original wheel with a dependency was not compliant
     # and check the one without a dependency was already compliant
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/' + orig_wheel)
     if with_dependency == '1':
-        assert (
-            '{orig_wheel} is consistent with the following platform tag: '
-            '"linux_{platform}"'
-        ).format(orig_wheel=orig_wheel, platform=PLATFORM) in output.replace('\n', ' ')
+        expected = f'linux_{PLATFORM}'
     else:
-        assert (
-            '{orig_wheel} is consistent with the following platform tag: '
-            '"{policy}"'
-        ).format(orig_wheel=orig_wheel, policy=policy) in output.replace('\n', ' ')
+        expected = policy
+    assert_show_output(manylinux_ctr, orig_wheel, expected, True)
 
     docker_exec(docker_python, 'pip install /io/' + repaired_wheel)
     docker_exec(
@@ -373,13 +410,13 @@ def test_build_wheel_with_image_dependencies(with_dependency, any_manylinux_cont
 
 
 def test_build_repair_pure_wheel(any_manylinux_container, io_folder):
-    policy, manylinux_ctr = any_manylinux_container
+    policy, tag, manylinux_ctr = any_manylinux_container
 
     if op.exists(op.join(WHEEL_CACHE_FOLDER, policy, ORIGINAL_SIX_WHEEL)):
         # If six has already been built and put in cache, let's reuse this.
         shutil.copy2(op.join(WHEEL_CACHE_FOLDER, policy,  ORIGINAL_SIX_WHEEL),
                      op.join(io_folder, ORIGINAL_SIX_WHEEL))
-        logger.info("Copied six wheel from {} to {}".format(WHEEL_CACHE_FOLDER, io_folder))
+        logger.info(f"Copied six wheel from {WHEEL_CACHE_FOLDER} to {io_folder}")
     else:
         docker_exec(manylinux_ctr, 'pip wheel -w /io --no-binary=:all: six==1.11.0')
         os.makedirs(op.join(WHEEL_CACHE_FOLDER, policy), exist_ok=True)
@@ -392,14 +429,11 @@ def test_build_repair_pure_wheel(any_manylinux_container, io_folder):
     assert 'manylinux' not in orig_wheel
 
     # Repair the wheel using the manylinux container
-    repair_command = (
-        'auditwheel repair --plat {policy} -w /io /io/{orig_wheel}'
-    ).format(policy=policy, orig_wheel=orig_wheel)
+    repair_command = f'auditwheel repair --plat {policy} -w /io /io/{orig_wheel}'
     output = docker_exec(manylinux_ctr, repair_command, expected_retcode=1)
     assert "This does not look like a platform wheel" in output
 
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/{orig_wheel}'
-                         .format(orig_wheel=orig_wheel),
+    output = docker_exec(manylinux_ctr, f'auditwheel show /io/{orig_wheel}',
                          expected_retcode=1)
     assert "This does not look like a platform wheel" in output
 
@@ -414,7 +448,7 @@ def test_build_wheel_depending_on_library_with_rpath(any_manylinux_container, do
     # - check if RPATH location is correct, i.e. it is inside .libs directory
     #   where all gathered libraries are put
 
-    policy, manylinux_ctr = any_manylinux_container
+    policy, tag, manylinux_ctr = any_manylinux_container
 
     docker_exec(
         manylinux_ctr,
@@ -424,45 +458,32 @@ def test_build_wheel_depending_on_library_with_rpath(any_manylinux_container, do
             (
                 'cd /auditwheel_src/tests/integration/testrpath '
                 '&& rm -rf build '
-                '&& DTAG={} python setup.py bdist_wheel -d /io'
-            ).format(dtag),
+                f'&& DTAG={dtag} python setup.py bdist_wheel -d /io'
+            ),
         ]
     )
     with open(op.join(op.dirname(__file__), 'testrpath', 'a', 'liba.so'), 'rb') as f:
         elf = ELFFile(f)
         dynamic = elf.get_section_by_name('.dynamic')
         tags = {t.entry.d_tag for t in dynamic.iter_tags()}
-        assert "DT_{}".format(dtag.upper()) in tags
+        assert f"DT_{dtag.upper()}" in tags
     filenames = os.listdir(io_folder)
-    assert filenames == ['testrpath-0.0.1-{}-linux_{}.whl'.format(PYTHON_ABI, PLATFORM)]
+    assert filenames == [f'testrpath-0.0.1-{PYTHON_ABI}-linux_{PLATFORM}.whl']
     orig_wheel = filenames[0]
     assert 'manylinux' not in orig_wheel
 
     # Repair the wheel using the appropriate manylinux container
-    repair_command = (
-        'auditwheel repair --plat {policy} -w /io /io/{orig_wheel}'
-    ).format(policy=policy, orig_wheel=orig_wheel)
+    repair_command = \
+        f'auditwheel repair --plat {policy} --only-plat -w /io /io/{orig_wheel}'
     docker_exec(
         manylinux_ctr,
         ['bash', '-c', 'LD_LIBRARY_PATH=/auditwheel_src/tests/integration/testrpath/a:$LD_LIBRARY_PATH ' + repair_command],
     )
     filenames = os.listdir(io_folder)
-    repaired_wheels = [fn for fn in filenames if policy in fn]
-    # Wheel picks up newer symbols when built in manylinux2010
-    expected_wheel_name = (
-        'testrpath-0.0.1-{abi}-{policy}.whl'
-    ).format(abi=PYTHON_ABI, policy=policy)
-    assert expected_wheel_name in repaired_wheels
-    repaired_wheel = expected_wheel_name
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/' + repaired_wheel)
-    if PLATFORM in {'x86_64', 'i686'}:
-        expect = 'manylinux1_{}'.format(PLATFORM)
-    else:
-        expect = 'manylinux2014_{}'.format(PLATFORM)
-    assert (
-        'testrpath-0.0.1-{abi}-{policy}.whl is consistent'
-        ' with the following platform tag: "{expect}"'
-    ).format(abi=PYTHON_ABI, policy=policy, expect=expect) in output.replace('\n', ' ')
+    assert len(filenames) == 2
+    repaired_wheel = f'testrpath-0.0.1-{PYTHON_ABI}-{tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, policy, False)
 
     docker_exec(docker_python, 'pip install /io/' + repaired_wheel)
     output = docker_exec(
@@ -485,7 +506,7 @@ def test_build_wheel_depending_on_library_with_rpath(any_manylinux_container, do
 
 def test_build_repair_multiple_top_level_modules_wheel(any_manylinux_container, docker_python, io_folder):
 
-    policy, manylinux_ctr = any_manylinux_container
+    policy, tag, manylinux_ctr = any_manylinux_container
 
     docker_exec(
         manylinux_ctr,
@@ -500,15 +521,13 @@ def test_build_repair_multiple_top_level_modules_wheel(any_manylinux_container,
 
     filenames = os.listdir(io_folder)
     assert filenames == [
-        'multiple_top_level-1.0-{abi}-linux_{platform}.whl'.format(
-            abi=PYTHON_ABI, platform=PLATFORM)]
+        f'multiple_top_level-1.0-{PYTHON_ABI}-linux_{PLATFORM}.whl']
     orig_wheel = filenames[0]
     assert 'manylinux' not in orig_wheel
 
     # Repair the wheel using the appropriate manylinux container
-    repair_command = (
-        'auditwheel repair --plat {policy} -w /io /io/{orig_wheel}'
-    ).format(policy=policy, orig_wheel=orig_wheel)
+    repair_command = \
+        f'auditwheel repair --plat {policy} --only-plat -w /io /io/{orig_wheel}'
     docker_exec(
         manylinux_ctr,
         [
@@ -524,22 +543,10 @@ def test_build_repair_multiple_top_level_modules_wheel(any_manylinux_container,
         ],
     )
     filenames = os.listdir(io_folder)
-    repaired_wheels = [fn for fn in filenames if policy in fn]
-    # Wheel picks up newer symbols when built in manylinux2010
-    expected_wheel_name = (
-        'multiple_top_level-1.0-{abi}-{policy}.whl'
-    ).format(abi=PYTHON_ABI, policy=policy)
-    assert repaired_wheels == [expected_wheel_name]
-    repaired_wheel = expected_wheel_name
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/' + repaired_wheel)
-    if PLATFORM in {'x86_64', 'i686'}:
-        expect = 'manylinux1_{}'.format(PLATFORM)
-    else:
-        expect = 'manylinux2014_{}'.format(PLATFORM)
-    assert (
-        '{wheel} is consistent'
-        ' with the following platform tag: "{expect}"'
-    ).format(wheel=repaired_wheel, expect=expect) in output.replace('\n', ' ')
+    assert len(filenames) == 2
+    repaired_wheel = f'multiple_top_level-1.0-{PYTHON_ABI}-{tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, policy, False)
 
     docker_exec(docker_python, 'pip install /io/' + repaired_wheel)
     for mod, func, expected in [
@@ -551,9 +558,7 @@ def test_build_repair_multiple_top_level_modules_wheel(any_manylinux_container,
             [
                 'python',
                 '-c',
-                'from {mod} import {func}; print({func}())'.format(
-                    mod=mod, func=func
-                ),
+                f'from {mod} import {func}; print({func}())',
             ],
         ).strip()
         assert output.strip() == expected
@@ -561,16 +566,14 @@ def test_build_repair_multiple_top_level_modules_wheel(any_manylinux_container,
         for lib_name in ['liba', 'libb']:
             assert any(
                 re.match(
-                    r'multiple_top_level.libs/{}.*\.so'.format(lib_name), name
+                    rf'multiple_top_level.libs/{lib_name}.*\.so', name
                 )
                 for name in w.namelist()
             )
 
 
 def test_build_repair_wheel_with_internal_rpath(any_manylinux_container, docker_python, io_folder):
-    
-
-    policy, manylinux_ctr = any_manylinux_container
+    policy, tag, manylinux_ctr = any_manylinux_container
 
     docker_exec(
         manylinux_ctr,
@@ -585,16 +588,13 @@ def test_build_repair_wheel_with_internal_rpath(any_manylinux_container, docker_
     )
 
     filenames = os.listdir(io_folder)
-    assert filenames == [
-        'internal_rpath-1.0-{abi}-linux_{platform}.whl'.format(
-            abi=PYTHON_ABI, platform=PLATFORM)]
+    assert filenames == [f'internal_rpath-1.0-{PYTHON_ABI}-linux_{PLATFORM}.whl']
     orig_wheel = filenames[0]
     assert 'manylinux' not in orig_wheel
     
     # Repair the wheel using the appropriate manylinux container
-    repair_command = (
-        'auditwheel repair --plat {policy} -w /io /io/{orig_wheel}'
-    ).format(policy=policy, orig_wheel=orig_wheel)
+    repair_command = \
+        f'auditwheel repair --plat {policy} --only-plat -w /io /io/{orig_wheel}'
     docker_exec(
         manylinux_ctr,
         [
@@ -609,22 +609,10 @@ def test_build_repair_wheel_with_internal_rpath(any_manylinux_container, docker_
         ],
     )
     filenames = os.listdir(io_folder)
-    repaired_wheels = [fn for fn in filenames if policy in fn]
-    # Wheel picks up newer symbols when built in manylinux2010
-    expected_wheel_name = (
-        'internal_rpath-1.0-{abi}-{policy}.whl'
-    ).format(abi=PYTHON_ABI, policy=policy)
-    assert repaired_wheels == [expected_wheel_name]
-    repaired_wheel = expected_wheel_name
-    output = docker_exec(manylinux_ctr, 'auditwheel show /io/' + repaired_wheel)
-    if PLATFORM in {'x86_64', 'i686'}:
-        expect = 'manylinux1_{}'.format(PLATFORM)
-    else:
-        expect = 'manylinux2014_{}'.format(PLATFORM)
-    assert (
-        '{wheel} is consistent'
-        ' with the following platform tag: "{expect}"'
-    ).format(wheel=repaired_wheel, expect=expect) in output.replace('\n', ' ')
+    assert len(filenames) == 2
+    repaired_wheel = f'internal_rpath-1.0-{PYTHON_ABI}-{tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, policy, False)
 
     docker_exec(docker_python, 'pip install /io/' + repaired_wheel)
     for mod, func, expected in [
@@ -636,9 +624,7 @@ def test_build_repair_wheel_with_internal_rpath(any_manylinux_container, docker_
             [
                 'python',
                 '-c',
-                'from internal_rpath.{mod} import {func}; print({func}())'.format(
-                    mod=mod, func=func
-                ),
+                f'from internal_rpath.{mod} import {func}; print({func}())',
             ],
         ).strip()
         assert output.strip() == expected
@@ -646,7 +632,126 @@ def test_build_repair_wheel_with_internal_rpath(any_manylinux_container, docker_
         for lib_name in ['libb']:
             assert any(
                 re.match(
-                    r'internal_rpath.libs/{}.*\.so'.format(lib_name), name
+                    rf'internal_rpath.libs/{lib_name}.*\.so', name
                 )
                 for name in w.namelist()
             )
+
+
+def test_strip_wheel(any_manylinux_container, docker_python, io_folder):
+    policy, tag, manylinux_ctr = any_manylinux_container
+    docker_exec(
+        manylinux_ctr,
+        ['bash', '-c', 'cd /auditwheel_src/tests/integration/sample_extension '
+                       '&& python -m pip wheel --no-deps -w /io .']
+    )
+
+    orig_wheel, *_ = os.listdir(io_folder)
+    assert orig_wheel.startswith("sample_extension-0.1.0")
+
+    # Repair the wheel using the appropriate manylinux container
+    repair_command = \
+        f'auditwheel repair --plat {policy} --strip -w /io /io/{orig_wheel}'
+    docker_exec(manylinux_ctr, repair_command)
+
+    repaired_wheel, *_ = glob.glob(f"{io_folder}/*{policy}*.whl")
+    repaired_wheel = os.path.basename(repaired_wheel)
+
+    docker_exec(docker_python, "pip install /io/" + repaired_wheel)
+    output = docker_exec(
+        docker_python,
+        ["python", "-c", "from sample_extension import test_func; print(test_func(1))"]
+    )
+    assert output.strip() == "2"
+
+
+@pytest.mark.parametrize(
+    'target_policy',
+    [f'{p}_{PLATFORM}' for p in list(MANYLINUX_IMAGES.keys())] +
+    [f'{p}_{PLATFORM}' for aliases in POLICY_ALIASES.values() for p in aliases]
+)
+@pytest.mark.parametrize('only_plat', [True, False])
+def test_build_wheel_compat(target_policy, only_plat, any_manylinux_container,
+                            docker_python, io_folder):
+    # test building wheels with compatibility with older spec
+    # check aliases for older spec
+
+    policy, tag, manylinux_ctr = any_manylinux_container
+
+    docker_exec(manylinux_ctr, [
+        'bash', '-c', 'cd /auditwheel_src/tests/integration/testsimple '
+                      '&& python -m pip wheel --no-deps -w /io .'
+    ])
+
+    filenames = os.listdir(io_folder)
+    orig_wheel = filenames[0]
+    assert 'manylinux' not in orig_wheel
+
+    if PLATFORM in {'x86_64', 'i686'}:
+        expect = f'manylinux_2_5_{PLATFORM}'
+        expect_tag = f'manylinux_2_5_{PLATFORM}.manylinux1_{PLATFORM}'
+    else:
+        expect = f'manylinux_2_17_{PLATFORM}'
+        expect_tag = f'manylinux_2_17_{PLATFORM}.manylinux2014_{PLATFORM}'
+
+    target_tag = target_policy
+    for pep600_policy, aliases in POLICY_ALIASES.items():
+        policy_ = f'{pep600_policy}_{PLATFORM}'
+        aliases_ = [f'{p}_{PLATFORM}' for p in aliases]
+        if target_policy == policy_ or target_policy in aliases_:
+            target_tag = f'{policy_}.{".".join(aliases_)}'
+
+    only_plat_arg = '--only-plat' if only_plat else ''
+    # we shall ba able to repair the wheel for all targets
+    docker_exec(manylinux_ctr, [
+        'bash', '-c',
+        f'auditwheel -v repair --plat {target_policy} {only_plat_arg} -w /io'
+        f' /io/{orig_wheel}'])
+    filenames = os.listdir(io_folder)
+    assert len(filenames) == 2
+    if only_plat or target_tag == expect_tag:
+        repaired_tag = target_tag
+    else:
+        repaired_tag = f'{expect_tag}.{target_tag}'
+    repaired_wheel = f'testsimple-0.0.1-{PYTHON_ABI}-{repaired_tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, expect, True)
+
+    docker_exec(docker_python, f'pip install /io/{repaired_wheel}')
+    docker_exec(
+        docker_python,
+        ['python', '-c',
+         'from sys import exit; from testsimple import run; exit(run())']
+    )
+
+
+def test_nonpy_rpath(any_manylinux_container, docker_python, io_folder):
+    # Tests https://github.com/pypa/auditwheel/issues/136
+    policy, tag, manylinux_ctr = any_manylinux_container
+    docker_exec(
+        manylinux_ctr,
+        ['bash', '-c', 'cd /auditwheel_src/tests/integration/nonpy_rpath '
+                       '&& python -m pip wheel --no-deps -w /io .']
+    )
+
+    orig_wheel, *_ = os.listdir(io_folder)
+    assert orig_wheel.startswith("nonpy_rpath-0.1.0")
+    assert 'manylinux' not in orig_wheel
+
+    # Repair the wheel using the appropriate manylinux container
+    repair_command = \
+        f'auditwheel repair --plat {policy} --only-plat -w /io /io/{orig_wheel}'
+    docker_exec(manylinux_ctr, repair_command)
+    filenames = os.listdir(io_folder)
+    assert len(filenames) == 2
+    repaired_wheel = f'nonpy_rpath-0.1.0-{PYTHON_ABI}-{tag}.whl'
+    assert repaired_wheel in filenames
+    assert_show_output(manylinux_ctr, repaired_wheel, policy, False)
+
+    # Test the resulting wheel outside the manylinux container
+    docker_exec(docker_python, "pip install /io/" + repaired_wheel)
+    docker_exec(
+        docker_python,
+        ["python", "-c",
+         "import nonpy_rpath; assert nonpy_rpath.crypt_something().startswith('*')"]
+    )
