@@ -3,7 +3,7 @@ import subprocess
 from os import path
 from os import getenv
 
-cmd = 'gcc -shared -fPIC -D_GNU_SOURCE dependency.c -o libdependency.so'
+cmd = 'gcc -shared -fPIC -D_GNU_SOURCE dependency.c -o libdependency.so -lm -lc'
 subprocess.check_call(cmd.split())
 
 define_macros = [('_GNU_SOURCE', None)]
@@ -15,6 +15,8 @@ if getenv('WITH_DEPENDENCY', '0') == '1':
     library_dirs.append(path.abspath(path.dirname(__file__)))
     define_macros.append(('WITH_DEPENDENCY', '1'))
 
+libraries.extend(['m', 'c'])
+
 setup(
     name='testdependencies',
     version='0.0.1',
